import { Construct } from 'constructs';
import { TerraformResource } from 'cdktf';
import { TerraformMetaArguments } from 'cdktf';
/**
 *
 */
export interface DefaultServiceAccountConfig extends TerraformMetaArguments {
    /**
     * True to enable automatic mounting of the service account token.
     */
    readonly automountServiceAccountToken?: boolean;
    /**
     * image_pull_secret block.
     */
    readonly imagePullSecret?: DefaultServiceAccountImagePullSecret[];
    /**
     * metadata block.
     */
    readonly metadata: DefaultServiceAccountMetadata[];
    /**
     * secret block.
     */
    readonly secret?: DefaultServiceAccountSecret[];
    /**
     * timeouts block.
     */
    readonly timeouts?: DefaultServiceAccountTimeouts;
}
/**
 *
 */
export interface DefaultServiceAccountImagePullSecret {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
}
/**
 *
 */
export interface DefaultServiceAccountMetadata {
    /**
     * An unstructured key value map stored with the service account that may be used to store arbitrary metadata.
     *
     * More info: http://kubernetes.io/docs/user-guide/annotations
     */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
     * Map of string keys and values that can be used to organize and categorize (scope and select) the service account.
     *
     * May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
     */
    readonly labels?: {
        [key: string]: string;
    };
    /**
     * Name of the service account, must be unique.
     *
     * Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
    /**
     * Namespace defines the space within which name of the service account must be unique.
     */
    readonly namespace?: string;
}
/**
 *
 */
export interface DefaultServiceAccountSecret {
    /**
     * Name of the referent.
     *
     * More info: http://kubernetes.io/docs/user-guide/identifiers#names
     */
    readonly name?: string;
}
/**
 *
 */
export interface DefaultServiceAccountTimeouts {
    /**
     *
     */
    readonly create?: string;
}
/**
 *
 */
export declare class DefaultServiceAccount extends TerraformResource {
    /**
     *
     */
    constructor(scope: Construct, id: string, config: DefaultServiceAccountConfig);
    private _automountServiceAccountToken?;
    /**
     *
     */
    get automountServiceAccountToken(): boolean;
    /**
     *
     */
    set automountServiceAccountToken(value: boolean);
    /**
     *
     */
    resetAutomountServiceAccountToken(): void;
    /**
     *
     */
    get automountServiceAccountTokenInput(): boolean | undefined;
    /**
     *
     */
    get defaultSecretName(): string;
    /**
     *
     */
    get id(): string;
    private _imagePullSecret?;
    /**
     *
     */
    get imagePullSecret(): DefaultServiceAccountImagePullSecret[];
    /**
     *
     */
    set imagePullSecret(value: DefaultServiceAccountImagePullSecret[]);
    /**
     *
     */
    resetImagePullSecret(): void;
    /**
     *
     */
    get imagePullSecretInput(): DefaultServiceAccountImagePullSecret[] | undefined;
    private _metadata;
    /**
     *
     */
    get metadata(): DefaultServiceAccountMetadata[];
    /**
     *
     */
    set metadata(value: DefaultServiceAccountMetadata[]);
    /**
     *
     */
    get metadataInput(): DefaultServiceAccountMetadata[];
    private _secret?;
    /**
     *
     */
    get secret(): DefaultServiceAccountSecret[];
    /**
     *
     */
    set secret(value: DefaultServiceAccountSecret[]);
    /**
     *
     */
    resetSecret(): void;
    /**
     *
     */
    get secretInput(): DefaultServiceAccountSecret[] | undefined;
    private _timeouts?;
    /**
     *
     */
    get timeouts(): DefaultServiceAccountTimeouts;
    /**
     *
     */
    set timeouts(value: DefaultServiceAccountTimeouts);
    /**
     *
     */
    resetTimeouts(): void;
    /**
     *
     */
    get timeoutsInput(): DefaultServiceAccountTimeouts | undefined;
    /**
     *
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
